<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/*                                                                        */
/* Polish translation by Nordavind(Bolo) (http://forum.phpnuke.org.pl)   */
/*                                                                        */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_YES","Tak");
define("_NO","Nie");
define("_OPTIONAL","(opcjonalnie)");
define("_REQUIRED","(wymagane)");
define("_SAVECHANGES","Zapisz zmiany");
define("_THRESHOLD","Prg");
define("_NOCOMMENTS","Bez komentarza");
define("_NESTED","Zagniedony");
define("_FLAT","Paski");
define("_THREAD","Wtek");
define("_OLDEST","Starsze jako pierwsze");
define("_NEWEST","Nowsze jako pierwsze");
define("_HIGHEST","Najpierw najwyej oceniane");
define("_ERRORINVEMAIL","BD: Niepoprawny adres e-mail");
define("_ERROREMAILSPACES","BD: Adres e-mail nie zawiera spacji");
define("_ERRORINVNICK","BD: Niepoprawny pseudonim");
define("_NICK2LONG","Pseudonim jest za dugi. Moe zawiera najwyej 25 znakw");
define("_NAMERESERVED","BD: Ta nazwa jest zarezerwowana");
define("_NICKNOSPACES","BD: Nie moe by spacji w pseudonimie");
define("_NICKTAKEN","BD: Taki pseudonim ju istnieje");
define("_EMAILREGISTERED","BD: Adres e-mail jest ju zarejestrowany");
define("_UUSERNAME","Nazwa uytkownika");
define("_FINISH","Koniec");
define("_YOUUSEDEMAIL","Ty lub kto inny uywa tego adresu email");
define("_TOREGISTER","aby zaoy konto na");
define("_FOLLOWINGMEM","Poniej s informacje o uytkowniku:");
define("_UNICKNAME","-Pseudonim:");
define("_UPASSWORD","-Haso:");
define("_USERPASS4","Haso uytkownika dla");
define("_YOUAREREGISTERED","Teraz ju jeste zarejestrowany(a). Powiniene otrzyma haso na podany adres email.");
define("_THISISYOURPAGE","To Twoja osobista strona");
define("_AVATAR","Logo");
define("_WEBSITE","Strona WWW");
define("_ICQ","Numer ICQ");
define("_AIM","Numer AIM");
define("_YIM","Numer YIM");
define("_MSNM","Numer MSNM");
define("_LOCATION","Adres");
define("_OCCUPATION","Zawd");
define("_INTERESTS","Zainteresowania");
define("_SIGNATURE","Podpis");
define("_MYHOMEPAGE","Strona WWW:");
define("_MYEMAIL","Adres e-mail:");
define("_EXTRAINFO","Dodatkowe informacje");
define("_NOINFOFOR","Brak dostpnego info na temat");
define("_LAST10COMMENTS","Ostatnie 10 komentarzy");
define("_LAST10SUBMISSIONS","Ostatnie 10 newsw wysanych przez");
define("_LOGININCOR","Logowanie nieprawidowe! Sprbuj jeszcze raz...");
define("_USERLOGIN","Logowanie uytkownika");
define("_USERREGLOGIN","Logowanie/Rejestracja uytkownika");
define("_REGNEWUSER","Rejestracja nowego uytkownika");
define("_LIST","Lista");
define("_NEWUSER","Nowy uytkownik");
define("_PASSWILLSEND","(haso zostanie przesane na podany adres)");
define("_COOKIEWARNING","Uwaga: preferencje bazuj na cookie's.");
define("_ASREGUSER","Jako zarejestrowany uytkownik moesz:");
define("_ASREG1","Wysya podpisane Twoim pseudonimem komentarze");
define("_ASREG2","Wysya podpisane Twoim pseudonimem newsy");
define("_ASREG3","Mie wasne menu na stronie gwnej");
define("_ASREG4","Wybra ilo wywietlanych na stronie gwnej newsw");
define("_ASREG5","Personalizowa komentarze");
define("_ASREG6","Wybra inn szat graficzn strony");
define("_ASREG7","...i kilka innych fajnych rzeczy...");
define("_REGISTERNOW","Zarejestruj si teraz! Masz to za darmo!");
define("_WEDONTGIVE","Nie sprzedajemy/oddajemy nikomu Twoich danych osobistych.");
define("_ALLOWEMAILVIEW","Pozwl innym uytkownikom na zobaczenie mojego adresu e-mail");
define("_OPTION","Opcje");
define("_PASSWORDLOST","Zapomniae hasa?");
define("_NOPROBLEM","Nie ma problemu. Po prostu wpisz swj pseudonim i kliknij na przycisk WYLIJ. Wylemy do Ciebie e-mail z Twoim kodem potwierdzajcym, wpisz wtedy ponownie swj pseudonim i kod potwierdzajcy a my wylemy Ci nowe haso.");
define("_CONFIRMATIONCODE","Kod potwierdzajcy");
define("_SENDPASSWORD","Wylij haso");
define("_YOUARELOGGEDOUT","Jeste wylogowany!");
define("_SORRYNOUSERINFO","Sorry, brak info na temat takiego uytkownika");
define("_USERACCOUNT","konto uytkownika");
define("_AT","na");
define("_HASTHISEMAIL","ma powizany ze sob adres e-mail.");
define("_AWEBUSERFROM","Uytkownik z ");
define("_HASREQUESTED","zada wysania hasa.");
define("_YOURNEWPASSWORD","Twoje nowe haso to:");
define("_YOUCANCHANGE","Moesz je zmieni po zalogowaniu si");
define("_IFYOUDIDNOTASK","Jeli o to nie pytae, nie przejmuj si. Tylko Ty widzisz t wiadomo. Jeeli to bd, po prostu zaloguj si z nowym hasem.");
define("_UPDATEFAILED","Nie mona uaktualni wpisu uytkownika. Prosz skontaktowa si z administratorem.");
define("_PASSWORD4","Haso dla");
define("_MAILED","wysane.");
define("_CODEREQUESTED","wanie poprosi o kod potwierdzajcy do zmiany hasa.");
define("_YOURCODEIS","Twj kod potwierdzajcy to:");
define("_WITHTHISCODE","Z tym kodem moesz zmieni haso dla");
define("_IFYOUDIDNOTASK2","Jeli nie prosie o to, nie przejmuj si. Po prostu skasuj ten mail.");
define("_CODEFOR","Kod potwierdzajcy dla");
define("_USERPASSWORD4","Haso uytkownika dla");
define("_UREALNAME","Prawdziwe imi");
define("_UREALEMAIL","Prawdziwy adres email");
define("_EMAILNOTPUBLIC","(ten adres e-mail nie bdzie opublikowany, ale jest wymagany do wysania Ci hasa w przypadku, gdy go zapomnisz)");
define("_UFAKEMAIL","Drugi adres e-mail");
define("_EMAILPUBLIC","(ten e-mail bdzie opublikowany. Wpisz jeli chesz, pamitaj o moliwym spamie)");
define("_YOURHOMEPAGE","Twoja strona WWW");
define("_YOURAVATAR","Twoje logo");
define("_YICQ","Twoje ICQ");
define("_YAIM","Twoje AIM");
define("_YYIM","Twoje YIM");
define("_YMSNM","Twoje MSNM");
define("_YLOCATION","Twj adres");
define("_YOCCUPATION","Twj zawd");
define("_YINTERESTS","Twoje zainteresowania");
define("_255CHARMAX","(Maks. 255 znakw. Wpisz swj podpis w kodzie HTML)");
define("_CANKNOWABOUT","(Maks. 255 znakw. Napisz, co inni maj wiedzie o Tobie)");
define("_TYPENEWPASSWORD","(aby zmieni haso, wpisz je dwukrotnie)");
define("_SOMETHINGWRONG","Co spierniczye(a)... Czyby tego nie lubi(a)?");
define("_PASSDIFFERENT","Wpisane hasa s rne. Musz by identyczne.");
define("_CHARLONG","znakw");
define("_AVAILABLEAVATARS","Dostpna lista logosw");
define("_NEWSINHOME","Liczba newsw");
define("_MAX127","(maks. 127):");
define("_ACTIVATEPERSONAL","Aktywuj osobiste menu");
define("_CHECKTHISOPTION","(sprawd t opcj i poniszy tekst wywietlany na stronie gwnej)");
define("_YOUCANUSEHTML","(moesz uywa HTML do umieszczania linkw, na przykad)");
define("_SELECTTHEME","Wybierz jeden z motyww");
define("_THEMETEXT1","Ta opcja zmieni wygld caej witryny.");
define("_THEMETEXT2","Zmiany bd wane tylko dla Ciebie.");
define("_THEMETEXT3","Kady uytkownik moe oglda t witryn z innym motywem.");
define("_DISPLAYMODE","Sposb wywietlania");
define("_SORTORDER","Porzdek sortowania");
define("_COMMENTSWILLIGNORED","Komentarze z wynikiem mniejszym ni ten ustawiony bd ignorowane.");
define("_UNCUT","Nieformatowany");
define("_EVERYTHING","Prawie wszystko");
define("_FILTERMOSTANON","Odfiltruj wikszo anonimowych");
define("_USCORE","Wynik");
define("_SCORENOTE","Anonimowe posty zaczynaj si od 0, logowane posty od 1. Moderatorzy dodaj i odejmuj punkty.");
define("_NOSCORES","Nie wywietlaj wynikw");
define("_HIDDESCORES","(ukryte wyniki: wci aktualne, ale ju nie wywietlane.)");
define("_MAXCOMMENT","Maksymalna dugo komentarza");
define("_TRUNCATES","(ucina dugie komentarze i dodaje link Czytaj wicej. Ustaw naprawd sporo, aby wyczy)");
define("_BYTESNOTE","bajtw (1024 bajty = 1K)");
define("_USENDPRIVATEMSG","Wylij prywatn wiadomo do");
define("_THEMESELECTION","Wybr motywu");
define("_COMMENTSCONFIG","Konfiguracja komentarzy");
define("_HOMECONFIG","Konfiguracja strony gwnej");
define("_PERSONALINFO","Informacje osobiste");
define("_USERSTATUS","Aktualny status uytkownika");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Zmie swoje info");
define("_CONFIGCOMMENTS","Ustawienia komentarzy");
define("_CHANGEHOME","Zmie stron gwna");
define("_LOGOUTEXIT","Wylogowanie/Wyjcie");
define("_SELECTTHETHEME","Wybierz motyw");
define("_PRIVATEMESSAGES","Twoje prywatne wiadomoci");
define("_EDITUSER","Edytuj uytkownika");
define("_RECEIVENEWSLETTER","Czy chcesz otrzymywa newsletter mailem?");
define("_NOTSUBSCRIBED","Nie jeste subskrybentem newslettera");
define("_SUBSCRIBED","Jeste subskrybentem newslettera");
define("_USERCHECKDATA","Sprawd ponisze informacje. Jeli wszystkie dane s poprawne, moesz kontynuowa rejestracj klikajc przycisk \"Zakocz\", w przeciwnym wypadku \"Wr\" i zmie to, co potrzeba.");
define("_USERFINALSTEP","Rejestracja nowego uytkownika: ostatni krok");
define("_ACCOUNTCREATED","Nowe konto zostao utworzone!");
define("_THANKSUSER","Dzikujemy za rejestracj na");
define("_YOUCANLOGIN","Za kilka sekund otrzymasz od naszego systemu wiadomo e-mail z Twoim hasem. Wwczas bdziesz mg zalogowa si <a href=\"modules.php?name=Your_Account\">tutaj</a>. Pamitaj aby zmieni sobie haso i ustawienia preferencji Twojego konta. Liczymy na to, e bdziesz zadowolony(a) z naszego serwisu.");
define("_BROWSEUSERS","Przegldaj uytkownikw");
define("_SEARCHUSERS","Szukaj uytkownikw");
define("_BROADCAST","Wylij wiadomo publiczn");
define("_BROADCASTTEXT","Moesz tutaj wysa <i>Publiczn Wiadomo</i> (maksimum 255 znakw). Przez najblisze 10 minut zobacz j wszyscy uytkownicy online. Kady uytkownik zobaczy Twoj wiadomo w czerwonym pasku pod logo. Uytkownik moe deaktywowa t opcj <a href=\"modules.php?name=Your_Account&amp;op=edithome\">tutaj</a>. Prosimy nie wysya spamu. HTML jest zabroniony.");
define("_SEND","Wylij");
define("_MESSAGEACTIVATE","Aktywowa rozsyanie wiadomoci publicznych?");
define("_BROADCASTSENT","Twoja wiadomo zostaa wysana.");
define("_BROADCASTNOTSENT","<b>BD:</b> Brakuje treci w Twojej wiadomoci lub przed chwil ju wysyae(a). By wysa kolejn wiadomo, musisz odczeka ok. 10 minut.");
define("_RETURNPAGE","Wr do swojej strony");
define("_MYHEADLINES","Moje nagwki");
define("_SELECTASITE","Wybierz stron z ktrej chcesz czyta nagwki:");
define("_SELECTASITE2","Wybierz stron");
define("_ORTYPEURL","lub wpisz adres pliku RSS/XML nagwkw wybranej przez Ciebie strony:");
define("_GO","OK");
define("_HEADLINESFROM","Nagwki ze strony");
define("_WEBMAIL", "Poczta");
define("_MESSAGES","Wiadomoci");
define("_RETURNACCOUNT", "Wr do zarzdzania Twoim kontem");
define("_ACCESSTO", "Dostp dla");
define("_CREATEJOURNAL", "Stwrz swj wasny dziennik");
define("_READHEADLINES", "Czytaj wybrane nagwki");

?>